// AUTO-GENERATED BY UpdateGenVersion.bat c11eaa82f10ba603983ebe57ed6a2d0206a21fbb
const char GenVersion_Version[] = "0.4.4-dev";
const char GenVersion_Commit[] = "c11eaa82f10ba603983ebe57ed6a2d0206a21fbb";
